@@ -46,3 +46,14 @@ def delete_v1_purge_id(ids):
     payload = {"id": ids}
     res = requests.delete(url, headers=headers, params=payload)
     return res
+
+
+def delete_v1_purge_filter(purge_filter):
+    """
+    Deletes Data Objects based on the given Filter.
+    """
+    url = inforlogin.base_url() + "/IONSERVICES/datalakeapi/v1/purge/filter"
+    headers = inforlogin.header()
+    payload = {"filter": purge_filter}
+    res = requests.delete(url, headers=headers, params=payload)
+    return res
